summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlightgroupedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlightgroupedit.h')
-rw-r--r--kpovmodeler/pmlightgroupedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmlightgroupedit.h b/kpovmodeler/pmlightgroupedit.h
index fa090f97..8b1216fd 100644
--- a/kpovmodeler/pmlightgroupedit.h
+++ b/kpovmodeler/pmlightgroupedit.h
@@ -35,12 +35,13 @@ class TQCheckBox;
class PMLightGroupEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMLightGroupEdit with parent and name
*/
- PMLightGroupEdit( TQWidget* parent, const char* name = 0 );
+ PMLightGroupEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMLightGroupEdit with parent and name
+ * Creates a PMLightGroupEdit with tqparent and name
*/